@@ -272,3 +272,11 @@ comma <- function(x, at_most = 20) {
   }
   paste(x, collapse = ", ")
 }
+
+menu <- function(...) {
+  utils::menu(...)
+}
+
+file.info <- function(...) {
+  base::file.info(...)
+}
